Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package Package v1alpha1 is the v1alpha1 version of the emrserverless.services.k8s.aws API. +groupName=emrserverless.services.k8s.aws
Index ¶
- Variables
- type Application
- type ApplicationList
- type ApplicationSpec
- type ApplicationState
- type ApplicationStatus
- type ApplicationSummary
- type Application_SDK
- type Architecture
- type AutoStartConfig
- type AutoStopConfig
- type CloudWatchLoggingConfiguration
- type Configuration
- type ConfigurationOverrides
- type DiskEncryptionConfiguration
- type IdentityCenterConfiguration
- type IdentityCenterConfigurationInput
- type ImageConfiguration
- type ImageConfigurationInput
- type InitialCapacityConfig
- type InteractiveConfiguration
- type JobLevelCostAllocationConfiguration
- type JobRun
- type JobRunAttemptSummary
- type JobRunMode
- type JobRunState
- type JobRunSummary
- type ManagedPersistenceMonitoringConfiguration
- type MaximumAllowedResources
- type MonitoringConfiguration
- type NetworkConfiguration
- type PrometheusMonitoringConfiguration
- type RetryPolicy
- type S3MonitoringConfiguration
- type SchedulerConfiguration
- type WorkerResourceConfig
- type WorkerTypeSpecification
- type WorkerTypeSpecificationInput
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is the API Group Version used to register the objects GroupVersion = schema.GroupVersion{Group: "emrserverless.services.k8s.aws", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Application ¶
type Application struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ApplicationSpec `json:"spec,omitempty"`
Status ApplicationStatus `json:"status,omitempty"`
}
Application is the Schema for the Applications API +kubebuilder:object:root=true +kubebuilder:subresource:status
func (*Application) DeepCopy ¶
func (in *Application) DeepCopy() *Application
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Application.
func (*Application) DeepCopyInto ¶
func (in *Application) DeepCopyInto(out *Application)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Application) DeepCopyObject ¶
func (in *Application) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ApplicationList ¶
type ApplicationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Application `json:"items"`
}
ApplicationList contains a list of Application +kubebuilder:object:root=true
func (*ApplicationList) DeepCopy ¶
func (in *ApplicationList) DeepCopy() *ApplicationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationList.
func (*ApplicationList) DeepCopyInto ¶
func (in *ApplicationList) DeepCopyInto(out *ApplicationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ApplicationList) DeepCopyObject ¶
func (in *ApplicationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ApplicationSpec ¶
type ApplicationSpec struct {
// The CPU architecture of an application.
Architecture *string `json:"architecture,omitempty"`
// The configuration for an application to automatically start on job submission.
AutoStartConfiguration *AutoStartConfig `json:"autoStartConfiguration,omitempty"`
// The configuration for an application to automatically stop after a certain
// amount of time being idle.
AutoStopConfiguration *AutoStopConfig `json:"autoStopConfiguration,omitempty"`
// The configuration object that allows encrypting local disks.
DiskEncryptionConfiguration *DiskEncryptionConfiguration `json:"diskEncryptionConfiguration,omitempty"`
// The IAM Identity Center Configuration accepts the Identity Center instance
// parameter required to enable trusted identity propagation. This configuration
// allows identity propagation between integrated services and the Identity
// Center instance.
IdentityCenterConfiguration *IdentityCenterConfigurationInput `json:"identityCenterConfiguration,omitempty"`
// The image configuration for all worker types. You can either set this parameter
// or imageConfiguration for each worker type in workerTypeSpecifications.
ImageConfiguration *ImageConfigurationInput `json:"imageConfiguration,omitempty"`
// The capacity to initialize when the application is created.
InitialCapacity map[string]*InitialCapacityConfig `json:"initialCapacity,omitempty"`
// The interactive configuration object that enables the interactive use cases
// to use when running an application.
InteractiveConfiguration *InteractiveConfiguration `json:"interactiveConfiguration,omitempty"`
// The configuration object that enables job level cost allocation.
JobLevelCostAllocationConfiguration *JobLevelCostAllocationConfiguration `json:"jobLevelCostAllocationConfiguration,omitempty"`
// The maximum capacity to allocate when the application is created. This is
// cumulative across all workers at any given point in time, not just when an
// application is created. No new resources will be created once any one of
// the defined limits is hit.
MaximumCapacity *MaximumAllowedResources `json:"maximumCapacity,omitempty"`
// The configuration setting for monitoring.
MonitoringConfiguration *MonitoringConfiguration `json:"monitoringConfiguration,omitempty"`
// The name of the application.
//
// Regex Pattern: `^[A-Za-z0-9._/#-]+$`
Name *string `json:"name,omitempty"`
// The network configuration for customer VPC connectivity.
NetworkConfiguration *NetworkConfiguration `json:"networkConfiguration,omitempty"`
// The Amazon EMR release associated with the application.
//
// Regex Pattern: `^[A-Za-z0-9._/-]+$`
// +kubebuilder:validation:Required
ReleaseLabel *string `json:"releaseLabel"`
// The Configuration (https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_Configuration.html)
// specifications to use when creating an application. Each configuration consists
// of a classification and properties. This configuration is applied to all
// the job runs submitted under the application.
RuntimeConfiguration []*Configuration `json:"runtimeConfiguration,omitempty"`
// The scheduler configuration for batch and streaming jobs running on this
// application. Supported with release labels emr-7.0.0 and above.
SchedulerConfiguration *SchedulerConfiguration `json:"schedulerConfiguration,omitempty"`
// The tags assigned to the application.
Tags map[string]*string `json:"tags,omitempty"`
// The type of application you want to start, such as Spark or Hive.
// +kubebuilder:validation:Required
Type *string `json:"type,omitempty"`
// The specification applied to each worker type.
WorkerTypeSpecifications map[string]*WorkerTypeSpecification `json:"workerTypeSpecifications,omitempty"`
}
ApplicationSpec defines the desired state of Application.
Information about an application. Amazon EMR Serverless uses applications to run jobs.
func (*ApplicationSpec) DeepCopy ¶
func (in *ApplicationSpec) DeepCopy() *ApplicationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationSpec.
func (*ApplicationSpec) DeepCopyInto ¶
func (in *ApplicationSpec) DeepCopyInto(out *ApplicationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApplicationState ¶
type ApplicationState string
const ( ApplicationState_CREATING ApplicationState = "CREATING" ApplicationState_CREATED ApplicationState = "CREATED" ApplicationState_STARTING ApplicationState = "STARTING" ApplicationState_STARTED ApplicationState = "STARTED" ApplicationState_STOPPING ApplicationState = "STOPPING" ApplicationState_STOPPED ApplicationState = "STOPPED" ApplicationState_TERMINATED ApplicationState = "TERMINATED" )
type ApplicationStatus ¶
type ApplicationStatus struct {
// All CRs managed by ACK have a common `Status.ACKResourceMetadata` member
// that is used to contain resource sync state, account ownership,
// constructed ARN for the resource
// +kubebuilder:validation:Optional
ACKResourceMetadata *ackv1alpha1.ResourceMetadata `json:"ackResourceMetadata"`
// All CRs managed by ACK have a common `Status.Conditions` member that
// contains a collection of `ackv1alpha1.Condition` objects that describe
// the various terminal states of the CR and its backend AWS service API
// resource
// +kubebuilder:validation:Optional
Conditions []*ackv1alpha1.Condition `json:"conditions"`
// The date and time when the application run was created.
// +kubebuilder:validation:Optional
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// The output contains the application ID.
//
// Regex Pattern: `^[0-9a-z]+$`
// +kubebuilder:validation:Optional
ID *string `json:"id,omitempty"`
// The ARN of the EMR Serverless created IAM Identity Center Application that
// provides trusted-identity propagation.
//
// Regex Pattern: `^arn:(aws[a-zA-Z0-9-]*):sso::\d{12}:application/(sso)?ins-[a-zA-Z0-9-.]{16}/apl-[a-zA-Z0-9]{16}$`
// +kubebuilder:validation:Optional
IdentityCenterApplicationARN *string `json:"identityCenterApplicationARN,omitempty"`
// The SHA256 digest of the image URI. This indicates which specific image the
// application is configured for. The image digest doesn't exist until an application
// has started.
//
// Regex Pattern: `^sha256:[0-9a-f]{64}$`
// +kubebuilder:validation:Optional
ResolvedImageDigest *string `json:"resolvedImageDigest,omitempty"`
// The state of the application.
// +kubebuilder:validation:Optional
State *string `json:"state,omitempty"`
// The state details of the application.
//
// Regex Pattern: `.*\S.*`
// +kubebuilder:validation:Optional
StateDetails *string `json:"stateDetails,omitempty"`
// The date and time when the application run was last updated.
// +kubebuilder:validation:Optional
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
}
ApplicationStatus defines the observed state of Application
func (*ApplicationStatus) DeepCopy ¶
func (in *ApplicationStatus) DeepCopy() *ApplicationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationStatus.
func (*ApplicationStatus) DeepCopyInto ¶
func (in *ApplicationStatus) DeepCopyInto(out *ApplicationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApplicationSummary ¶
type ApplicationSummary struct {
Architecture *string `json:"architecture,omitempty"`
ARN *string `json:"arn,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
ID *string `json:"id,omitempty"`
Name *string `json:"name,omitempty"`
ReleaseLabel *string `json:"releaseLabel,omitempty"`
State *string `json:"state,omitempty"`
StateDetails *string `json:"stateDetails,omitempty"`
Type *string `json:"type_,omitempty"`
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
}
The summary of attributes associated with an application.
func (*ApplicationSummary) DeepCopy ¶
func (in *ApplicationSummary) DeepCopy() *ApplicationSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationSummary.
func (*ApplicationSummary) DeepCopyInto ¶
func (in *ApplicationSummary) DeepCopyInto(out *ApplicationSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Application_SDK ¶
type Application_SDK struct {
ApplicationID *string `json:"applicationID,omitempty"`
Architecture *string `json:"architecture,omitempty"`
ARN *string `json:"arn,omitempty"`
// The configuration for an application to automatically start on job submission.
AutoStartConfiguration *AutoStartConfig `json:"autoStartConfiguration,omitempty"`
// The configuration for an application to automatically stop after a certain
// amount of time being idle.
AutoStopConfiguration *AutoStopConfig `json:"autoStopConfiguration,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// The configuration object that allows encrypting local disks.
DiskEncryptionConfiguration *DiskEncryptionConfiguration `json:"diskEncryptionConfiguration,omitempty"`
// The IAM Identity Center Configuration accepts the Identity Center instance
// parameter required to enable trusted identity propagation. This configuration
// allows identity propagation between integrated services and the Identity
// Center instance.
IdentityCenterConfiguration *IdentityCenterConfiguration `json:"identityCenterConfiguration,omitempty"`
// The applied image configuration.
ImageConfiguration *ImageConfiguration `json:"imageConfiguration,omitempty"`
InitialCapacity map[string]*InitialCapacityConfig `json:"initialCapacity,omitempty"`
// The configuration to use to enable the different types of interactive use
// cases in an application.
InteractiveConfiguration *InteractiveConfiguration `json:"interactiveConfiguration,omitempty"`
// The configuration object that enables job level cost allocation.
JobLevelCostAllocationConfiguration *JobLevelCostAllocationConfiguration `json:"jobLevelCostAllocationConfiguration,omitempty"`
// The maximum allowed cumulative resources for an application. No new resources
// will be created once the limit is hit.
MaximumCapacity *MaximumAllowedResources `json:"maximumCapacity,omitempty"`
// The configuration setting for monitoring.
MonitoringConfiguration *MonitoringConfiguration `json:"monitoringConfiguration,omitempty"`
Name *string `json:"name,omitempty"`
// The network configuration for customer VPC connectivity.
NetworkConfiguration *NetworkConfiguration `json:"networkConfiguration,omitempty"`
ReleaseLabel *string `json:"releaseLabel,omitempty"`
RuntimeConfiguration []*Configuration `json:"runtimeConfiguration,omitempty"`
// The scheduler configuration for batch and streaming jobs running on this
// application. Supported with release labels emr-7.0.0 and above.
SchedulerConfiguration *SchedulerConfiguration `json:"schedulerConfiguration,omitempty"`
State *string `json:"state,omitempty"`
StateDetails *string `json:"stateDetails,omitempty"`
Tags map[string]*string `json:"tags,omitempty"`
Type *string `json:"type_,omitempty"`
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
WorkerTypeSpecifications map[string]*WorkerTypeSpecification `json:"workerTypeSpecifications,omitempty"`
}
Information about an application. Amazon EMR Serverless uses applications to run jobs.
func (*Application_SDK) DeepCopy ¶
func (in *Application_SDK) DeepCopy() *Application_SDK
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Application_SDK.
func (*Application_SDK) DeepCopyInto ¶
func (in *Application_SDK) DeepCopyInto(out *Application_SDK)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Architecture ¶
type Architecture string
const ( Architecture_ARM64 Architecture = "ARM64" Architecture_X86_64 Architecture = "X86_64" )
type AutoStartConfig ¶
type AutoStartConfig struct {
Enabled *bool `json:"enabled,omitempty"`
}
The configuration for an application to automatically start on job submission.
func (*AutoStartConfig) DeepCopy ¶
func (in *AutoStartConfig) DeepCopy() *AutoStartConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoStartConfig.
func (*AutoStartConfig) DeepCopyInto ¶
func (in *AutoStartConfig) DeepCopyInto(out *AutoStartConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AutoStopConfig ¶
type AutoStopConfig struct {
Enabled *bool `json:"enabled,omitempty"`
IdleTimeoutMinutes *int64 `json:"idleTimeoutMinutes,omitempty"`
}
The configuration for an application to automatically stop after a certain amount of time being idle.
func (*AutoStopConfig) DeepCopy ¶
func (in *AutoStopConfig) DeepCopy() *AutoStopConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoStopConfig.
func (*AutoStopConfig) DeepCopyInto ¶
func (in *AutoStopConfig) DeepCopyInto(out *AutoStopConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudWatchLoggingConfiguration ¶
type CloudWatchLoggingConfiguration struct {
Enabled *bool `json:"enabled,omitempty"`
EncryptionKeyARN *string `json:"encryptionKeyARN,omitempty"`
// Reference field for EncryptionKeyARN
EncryptionKeyRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"encryptionKeyRef,omitempty"`
LogGroupName *string `json:"logGroupName,omitempty"`
LogStreamNamePrefix *string `json:"logStreamNamePrefix,omitempty"`
LogTypes map[string][]*string `json:"logTypes,omitempty"`
}
The Amazon CloudWatch configuration for monitoring logs. You can configure your jobs to send log information to CloudWatch.
func (*CloudWatchLoggingConfiguration) DeepCopy ¶
func (in *CloudWatchLoggingConfiguration) DeepCopy() *CloudWatchLoggingConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudWatchLoggingConfiguration.
func (*CloudWatchLoggingConfiguration) DeepCopyInto ¶
func (in *CloudWatchLoggingConfiguration) DeepCopyInto(out *CloudWatchLoggingConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Configuration ¶
type Configuration struct {
Classification *string `json:"classification,omitempty"`
Properties map[string]*string `json:"properties,omitempty"`
}
A configuration specification to be used when provisioning an application. A configuration consists of a classification, properties, and optional nested configurations. A classification refers to an application-specific configuration file. Properties are the settings you want to change in that file.
func (*Configuration) DeepCopy ¶
func (in *Configuration) DeepCopy() *Configuration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Configuration.
func (*Configuration) DeepCopyInto ¶
func (in *Configuration) DeepCopyInto(out *Configuration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationOverrides ¶
type ConfigurationOverrides struct {
ApplicationConfiguration []*Configuration `json:"applicationConfiguration,omitempty"`
// The configuration object that allows encrypting local disks.
DiskEncryptionConfiguration *DiskEncryptionConfiguration `json:"diskEncryptionConfiguration,omitempty"`
// The configuration setting for monitoring.
MonitoringConfiguration *MonitoringConfiguration `json:"monitoringConfiguration,omitempty"`
}
A configuration specification to be used to override existing configurations.
func (*ConfigurationOverrides) DeepCopy ¶
func (in *ConfigurationOverrides) DeepCopy() *ConfigurationOverrides
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationOverrides.
func (*ConfigurationOverrides) DeepCopyInto ¶
func (in *ConfigurationOverrides) DeepCopyInto(out *ConfigurationOverrides)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DiskEncryptionConfiguration ¶
type DiskEncryptionConfiguration struct {
EncryptionContext map[string]*string `json:"encryptionContext,omitempty"`
EncryptionKeyARN *string `json:"encryptionKeyARN,omitempty"`
// Reference field for EncryptionKeyARN
EncryptionKeyRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"encryptionKeyRef,omitempty"`
}
The configuration object that allows encrypting local disks.
func (*DiskEncryptionConfiguration) DeepCopy ¶
func (in *DiskEncryptionConfiguration) DeepCopy() *DiskEncryptionConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskEncryptionConfiguration.
func (*DiskEncryptionConfiguration) DeepCopyInto ¶
func (in *DiskEncryptionConfiguration) DeepCopyInto(out *DiskEncryptionConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IdentityCenterConfiguration ¶
type IdentityCenterConfiguration struct {
IdentityCenterApplicationARN *string `json:"identityCenterApplicationARN,omitempty"`
IdentityCenterInstanceARN *string `json:"identityCenterInstanceARN,omitempty"`
UserBackgroundSessionsEnabled *bool `json:"userBackgroundSessionsEnabled,omitempty"`
}
The IAM Identity Center Configuration accepts the Identity Center instance parameter required to enable trusted identity propagation. This configuration allows identity propagation between integrated services and the Identity Center instance.
func (*IdentityCenterConfiguration) DeepCopy ¶
func (in *IdentityCenterConfiguration) DeepCopy() *IdentityCenterConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IdentityCenterConfiguration.
func (*IdentityCenterConfiguration) DeepCopyInto ¶
func (in *IdentityCenterConfiguration) DeepCopyInto(out *IdentityCenterConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IdentityCenterConfigurationInput ¶
type IdentityCenterConfigurationInput struct {
IdentityCenterInstanceARN *string `json:"identityCenterInstanceARN,omitempty"`
UserBackgroundSessionsEnabled *bool `json:"userBackgroundSessionsEnabled,omitempty"`
}
The IAM Identity Center Configuration accepts the Identity Center instance parameter required to enable trusted identity propagation. This configuration allows identity propagation between integrated services and the Identity Center instance.
func (*IdentityCenterConfigurationInput) DeepCopy ¶
func (in *IdentityCenterConfigurationInput) DeepCopy() *IdentityCenterConfigurationInput
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IdentityCenterConfigurationInput.
func (*IdentityCenterConfigurationInput) DeepCopyInto ¶
func (in *IdentityCenterConfigurationInput) DeepCopyInto(out *IdentityCenterConfigurationInput)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ImageConfiguration ¶
type ImageConfiguration struct {
ImageURI *string `json:"imageURI,omitempty"`
ResolvedImageDigest *string `json:"resolvedImageDigest,omitempty"`
}
The applied image configuration.
func (*ImageConfiguration) DeepCopy ¶
func (in *ImageConfiguration) DeepCopy() *ImageConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageConfiguration.
func (*ImageConfiguration) DeepCopyInto ¶
func (in *ImageConfiguration) DeepCopyInto(out *ImageConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ImageConfigurationInput ¶
type ImageConfigurationInput struct {
ImageURI *string `json:"imageURI,omitempty"`
}
The image configuration.
func (*ImageConfigurationInput) DeepCopy ¶
func (in *ImageConfigurationInput) DeepCopy() *ImageConfigurationInput
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageConfigurationInput.
func (*ImageConfigurationInput) DeepCopyInto ¶
func (in *ImageConfigurationInput) DeepCopyInto(out *ImageConfigurationInput)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InitialCapacityConfig ¶
type InitialCapacityConfig struct {
// The cumulative configuration requirements for every worker instance of the
// worker type.
WorkerConfiguration *WorkerResourceConfig `json:"workerConfiguration,omitempty"`
WorkerCount *int64 `json:"workerCount,omitempty"`
}
The initial capacity configuration per worker.
func (*InitialCapacityConfig) DeepCopy ¶
func (in *InitialCapacityConfig) DeepCopy() *InitialCapacityConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InitialCapacityConfig.
func (*InitialCapacityConfig) DeepCopyInto ¶
func (in *InitialCapacityConfig) DeepCopyInto(out *InitialCapacityConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InteractiveConfiguration ¶
type InteractiveConfiguration struct {
LivyEndpointEnabled *bool `json:"livyEndpointEnabled,omitempty"`
StudioEnabled *bool `json:"studioEnabled,omitempty"`
}
The configuration to use to enable the different types of interactive use cases in an application.
func (*InteractiveConfiguration) DeepCopy ¶
func (in *InteractiveConfiguration) DeepCopy() *InteractiveConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InteractiveConfiguration.
func (*InteractiveConfiguration) DeepCopyInto ¶
func (in *InteractiveConfiguration) DeepCopyInto(out *InteractiveConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobLevelCostAllocationConfiguration ¶
type JobLevelCostAllocationConfiguration struct {
Enabled *bool `json:"enabled,omitempty"`
}
The configuration object that enables job level cost allocation.
func (*JobLevelCostAllocationConfiguration) DeepCopy ¶
func (in *JobLevelCostAllocationConfiguration) DeepCopy() *JobLevelCostAllocationConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobLevelCostAllocationConfiguration.
func (*JobLevelCostAllocationConfiguration) DeepCopyInto ¶
func (in *JobLevelCostAllocationConfiguration) DeepCopyInto(out *JobLevelCostAllocationConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobRun ¶
type JobRun struct {
ApplicationID *string `json:"applicationID,omitempty"`
AttemptCreatedAt *metav1.Time `json:"attemptCreatedAt,omitempty"`
AttemptUpdatedAt *metav1.Time `json:"attemptUpdatedAt,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
EndedAt *metav1.Time `json:"endedAt,omitempty"`
Name *string `json:"name,omitempty"`
// The network configuration for customer VPC connectivity.
NetworkConfiguration *NetworkConfiguration `json:"networkConfiguration,omitempty"`
ReleaseLabel *string `json:"releaseLabel,omitempty"`
StartedAt *metav1.Time `json:"startedAt,omitempty"`
StateDetails *string `json:"stateDetails,omitempty"`
Tags map[string]*string `json:"tags,omitempty"`
TotalExecutionDurationSeconds *int64 `json:"totalExecutionDurationSeconds,omitempty"`
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
}
Information about a job run. A job run is a unit of work, such as a Spark JAR, Hive query, or SparkSQL query, that you submit to an Amazon EMR Serverless application.
func (*JobRun) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobRun.
func (*JobRun) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobRunAttemptSummary ¶
type JobRunAttemptSummary struct {
ApplicationID *string `json:"applicationID,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
JobCreatedAt *metav1.Time `json:"jobCreatedAt,omitempty"`
Name *string `json:"name,omitempty"`
ReleaseLabel *string `json:"releaseLabel,omitempty"`
StateDetails *string `json:"stateDetails,omitempty"`
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
}
The summary of attributes associated with a job run attempt.
func (*JobRunAttemptSummary) DeepCopy ¶
func (in *JobRunAttemptSummary) DeepCopy() *JobRunAttemptSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobRunAttemptSummary.
func (*JobRunAttemptSummary) DeepCopyInto ¶
func (in *JobRunAttemptSummary) DeepCopyInto(out *JobRunAttemptSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type JobRunMode ¶
type JobRunMode string
const ( JobRunMode_BATCH JobRunMode = "BATCH" JobRunMode_STREAMING JobRunMode = "STREAMING" )
type JobRunState ¶
type JobRunState string
const ( JobRunState_SUBMITTED JobRunState = "SUBMITTED" JobRunState_PENDING JobRunState = "PENDING" JobRunState_SCHEDULED JobRunState = "SCHEDULED" JobRunState_RUNNING JobRunState = "RUNNING" JobRunState_SUCCESS JobRunState = "SUCCESS" JobRunState_FAILED JobRunState = "FAILED" JobRunState_CANCELLING JobRunState = "CANCELLING" JobRunState_CANCELLED JobRunState = "CANCELLED" JobRunState_QUEUED JobRunState = "QUEUED" )
type JobRunSummary ¶
type JobRunSummary struct {
ApplicationID *string `json:"applicationID,omitempty"`
AttemptCreatedAt *metav1.Time `json:"attemptCreatedAt,omitempty"`
AttemptUpdatedAt *metav1.Time `json:"attemptUpdatedAt,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
Name *string `json:"name,omitempty"`
ReleaseLabel *string `json:"releaseLabel,omitempty"`
StateDetails *string `json:"stateDetails,omitempty"`
UpdatedAt *metav1.Time `json:"updatedAt,omitempty"`
}
The summary of attributes associated with a job run.
func (*JobRunSummary) DeepCopy ¶
func (in *JobRunSummary) DeepCopy() *JobRunSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JobRunSummary.
func (*JobRunSummary) DeepCopyInto ¶
func (in *JobRunSummary) DeepCopyInto(out *JobRunSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ManagedPersistenceMonitoringConfiguration ¶
type ManagedPersistenceMonitoringConfiguration struct {
Enabled *bool `json:"enabled,omitempty"`
EncryptionKeyARN *string `json:"encryptionKeyARN,omitempty"`
// Reference field for EncryptionKeyARN
EncryptionKeyRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"encryptionKeyRef,omitempty"`
}
The managed log persistence configuration for a job run.
func (*ManagedPersistenceMonitoringConfiguration) DeepCopy ¶
func (in *ManagedPersistenceMonitoringConfiguration) DeepCopy() *ManagedPersistenceMonitoringConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ManagedPersistenceMonitoringConfiguration.
func (*ManagedPersistenceMonitoringConfiguration) DeepCopyInto ¶
func (in *ManagedPersistenceMonitoringConfiguration) DeepCopyInto(out *ManagedPersistenceMonitoringConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MaximumAllowedResources ¶
type MaximumAllowedResources struct {
CPU *string `json:"cpu,omitempty"`
Disk *string `json:"disk,omitempty"`
Memory *string `json:"memory,omitempty"`
}
The maximum allowed cumulative resources for an application. No new resources will be created once the limit is hit.
func (*MaximumAllowedResources) DeepCopy ¶
func (in *MaximumAllowedResources) DeepCopy() *MaximumAllowedResources
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MaximumAllowedResources.
func (*MaximumAllowedResources) DeepCopyInto ¶
func (in *MaximumAllowedResources) DeepCopyInto(out *MaximumAllowedResources)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MonitoringConfiguration ¶
type MonitoringConfiguration struct {
// The Amazon CloudWatch configuration for monitoring logs. You can configure
// your jobs to send log information to CloudWatch.
CloudWatchLoggingConfiguration *CloudWatchLoggingConfiguration `json:"cloudWatchLoggingConfiguration,omitempty"`
// The managed log persistence configuration for a job run.
ManagedPersistenceMonitoringConfiguration *ManagedPersistenceMonitoringConfiguration `json:"managedPersistenceMonitoringConfiguration,omitempty"`
// The monitoring configuration object you can configure to send metrics to
// Amazon Managed Service for Prometheus for a job run.
PrometheusMonitoringConfiguration *PrometheusMonitoringConfiguration `json:"prometheusMonitoringConfiguration,omitempty"`
// The Amazon S3 configuration for monitoring log publishing. You can configure
// your jobs to send log information to Amazon S3.
S3MonitoringConfiguration *S3MonitoringConfiguration `json:"s3MonitoringConfiguration,omitempty"`
}
The configuration setting for monitoring.
func (*MonitoringConfiguration) DeepCopy ¶
func (in *MonitoringConfiguration) DeepCopy() *MonitoringConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MonitoringConfiguration.
func (*MonitoringConfiguration) DeepCopyInto ¶
func (in *MonitoringConfiguration) DeepCopyInto(out *MonitoringConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetworkConfiguration ¶
type NetworkConfiguration struct {
SecurityGroupIDs []*string `json:"securityGroupIDs,omitempty"`
// Reference field for SecurityGroupIDs
SecurityGroupRefs []*ackv1alpha1.AWSResourceReferenceWrapper `json:"securityGroupRefs,omitempty"`
SubnetIDs []*string `json:"subnetIDs,omitempty"`
// Reference field for SubnetIDs
SubnetRefs []*ackv1alpha1.AWSResourceReferenceWrapper `json:"subnetRefs,omitempty"`
}
The network configuration for customer VPC connectivity.
func (*NetworkConfiguration) DeepCopy ¶
func (in *NetworkConfiguration) DeepCopy() *NetworkConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkConfiguration.
func (*NetworkConfiguration) DeepCopyInto ¶
func (in *NetworkConfiguration) DeepCopyInto(out *NetworkConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrometheusMonitoringConfiguration ¶
type PrometheusMonitoringConfiguration struct {
RemoteWriteURL *string `json:"remoteWriteURL,omitempty"`
}
The monitoring configuration object you can configure to send metrics to Amazon Managed Service for Prometheus for a job run.
func (*PrometheusMonitoringConfiguration) DeepCopy ¶
func (in *PrometheusMonitoringConfiguration) DeepCopy() *PrometheusMonitoringConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrometheusMonitoringConfiguration.
func (*PrometheusMonitoringConfiguration) DeepCopyInto ¶
func (in *PrometheusMonitoringConfiguration) DeepCopyInto(out *PrometheusMonitoringConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RetryPolicy ¶
type RetryPolicy struct {
MaxFailedAttemptsPerHour *int64 `json:"maxFailedAttemptsPerHour,omitempty"`
}
The retry policy to use for a job run.
func (*RetryPolicy) DeepCopy ¶
func (in *RetryPolicy) DeepCopy() *RetryPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RetryPolicy.
func (*RetryPolicy) DeepCopyInto ¶
func (in *RetryPolicy) DeepCopyInto(out *RetryPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type S3MonitoringConfiguration ¶
type S3MonitoringConfiguration struct {
EncryptionKeyARN *string `json:"encryptionKeyARN,omitempty"`
// Reference field for EncryptionKeyARN
EncryptionKeyRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"encryptionKeyRef,omitempty"`
LogURI *string `json:"logURI,omitempty"`
}
The Amazon S3 configuration for monitoring log publishing. You can configure your jobs to send log information to Amazon S3.
func (*S3MonitoringConfiguration) DeepCopy ¶
func (in *S3MonitoringConfiguration) DeepCopy() *S3MonitoringConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new S3MonitoringConfiguration.
func (*S3MonitoringConfiguration) DeepCopyInto ¶
func (in *S3MonitoringConfiguration) DeepCopyInto(out *S3MonitoringConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SchedulerConfiguration ¶
type SchedulerConfiguration struct {
MaxConcurrentRuns *int64 `json:"maxConcurrentRuns,omitempty"`
QueueTimeoutMinutes *int64 `json:"queueTimeoutMinutes,omitempty"`
}
The scheduler configuration for batch and streaming jobs running on this application. Supported with release labels emr-7.0.0 and above.
func (*SchedulerConfiguration) DeepCopy ¶
func (in *SchedulerConfiguration) DeepCopy() *SchedulerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SchedulerConfiguration.
func (*SchedulerConfiguration) DeepCopyInto ¶
func (in *SchedulerConfiguration) DeepCopyInto(out *SchedulerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerResourceConfig ¶
type WorkerResourceConfig struct {
CPU *string `json:"cpu,omitempty"`
Disk *string `json:"disk,omitempty"`
DiskType *string `json:"diskType,omitempty"`
Memory *string `json:"memory,omitempty"`
}
The cumulative configuration requirements for every worker instance of the worker type.
func (*WorkerResourceConfig) DeepCopy ¶
func (in *WorkerResourceConfig) DeepCopy() *WorkerResourceConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerResourceConfig.
func (*WorkerResourceConfig) DeepCopyInto ¶
func (in *WorkerResourceConfig) DeepCopyInto(out *WorkerResourceConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerTypeSpecification ¶
type WorkerTypeSpecification struct {
// The applied image configuration.
ImageConfiguration *ImageConfiguration `json:"imageConfiguration,omitempty"`
}
The specifications for a worker type.
func (*WorkerTypeSpecification) DeepCopy ¶
func (in *WorkerTypeSpecification) DeepCopy() *WorkerTypeSpecification
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerTypeSpecification.
func (*WorkerTypeSpecification) DeepCopyInto ¶
func (in *WorkerTypeSpecification) DeepCopyInto(out *WorkerTypeSpecification)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerTypeSpecificationInput ¶
type WorkerTypeSpecificationInput struct {
// The image configuration.
ImageConfiguration *ImageConfigurationInput `json:"imageConfiguration,omitempty"`
}
The specifications for a worker type.
func (*WorkerTypeSpecificationInput) DeepCopy ¶
func (in *WorkerTypeSpecificationInput) DeepCopy() *WorkerTypeSpecificationInput
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerTypeSpecificationInput.
func (*WorkerTypeSpecificationInput) DeepCopyInto ¶
func (in *WorkerTypeSpecificationInput) DeepCopyInto(out *WorkerTypeSpecificationInput)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.